@@ -41,7 +41,15 @@ git diff --quiet && git diff --cached --quiet && [ -z "$(git ls-files --others -
 
 if [  "$?" != "0" ]; then
     echo x... git is not clean... do something about it
-    exit 1
+    YN=$(yes_or_no)
+    echo ... $YN ...
+    if [ "$YN" = "0" ]; then
+	echo x... AUTOCOMMIT .............
+	sleep 1
+	echo x... AUTOCOMMIT .............
+	sleep 1
+	git commit -a -m "debug with automatic commit"
+    fi
 fi
 
 
