@@ -172,6 +172,9 @@ def confirm_dialog(stdscr, prompt):
         elif c in (ord('n'), ord('N')):
             return False
 
+# ================================================================================
+#
+# --------------------------------------------------------------------------------
 
 def on_backup(stdscr):
     """
@@ -192,6 +195,10 @@ def on_backup(stdscr):
         maninf.backup_portable(PATH)
         logging.debug(f"Done backup to {PATH}")
 
+# ================================================================================
+#
+# --------------------------------------------------------------------------------
+
 def on_copy(name, dbase, other_dbase, stdscr, wordcopy="COPY", asking=True):
     logging.debug(f"copying - {name}/{dbase} -> {other_dbase};")
     if stdscr:
@@ -202,6 +209,7 @@ def on_copy(name, dbase, other_dbase, stdscr, wordcopy="COPY", asking=True):
             if (name is None) or (dbase is None) or (other_dbase is None):
                 pass
             else:
+                show_message_box(stdscr, "... preforming copy ...")
                 res = maninf.copy_measurement(name, dbase, other_dbase, silent=True)
                 logging.debug( f"{res}")
             logging.debug(f"copied '{name}'")
@@ -213,6 +221,10 @@ def on_copy(name, dbase, other_dbase, stdscr, wordcopy="COPY", asking=True):
         logging.debug(f"copied '{name}' without confirmation")
     pass
 
+# ================================================================================
+#
+# --------------------------------------------------------------------------------
+
 def on_move():
     logging.debug(f"moving - ;")
     pass
@@ -229,6 +241,7 @@ def on_delete_database(name, stdscr):
     if stdscr:
         confirm = confirm_dialog(stdscr, f"Delete database '{name}'?")
         if confirm:
+            show_message_box(stdscr, "... preforming drop db ...")
             maninf.drop_database(name)
             logging.debug(f"Deleted '{name}'")
         else:
@@ -249,6 +262,7 @@ def on_delete_measurement(name, database, stdscr, asking=True):
         if asking:
             confirm = confirm_dialog(stdscr, f"Delete measurement '{name}' of {database}?")
         if confirm:
+            show_message_box("... preforming delete ...")
             maninf.delete_measurement(name, database)
             logging.debug(f"Deleted measurement '{name}' from {database}")
         else:
@@ -570,6 +584,11 @@ def main(logfile, admin, test_only):
 
         while True:
             key = stdscr.getch()
+
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
+
             if key == 9:  # TAB
                 logging.debug(f" key TAB pressed   ")
                 active_panel = 'right' if active_panel == 'left' else 'left'
@@ -621,7 +640,9 @@ def main(logfile, admin, test_only):
                     if right_idx >= right_offset + h - 2:
                         right_offset += 1
 
-
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
 
             # ------------------------------------------------------------
             elif key == ord('2'):# --------------------------------- export measurement to csv file
@@ -649,7 +670,9 @@ def main(logfile, admin, test_only):
                     #show_message_box(stdscr, f"{res}")
                 refresh_panels()
 
-
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
 
             elif key == ord('3'):# --------------------------------- View measurement
                 logging.debug(f" key {chr(key)} pressed   ")
@@ -670,7 +693,9 @@ def main(logfile, admin, test_only):
                         text = ""
                         if selected_item.find(".exported") > 0:
                             nm1 = selected_item.split(".exported")[0]
-                            text = f"... exported database: \n {nm1}"
+                            filepath = os.path.join(DISK_MIRROR_PATH, selected_item)
+                            oldname = maninf.restore_portable_get_oldname(filepath, database=nm1)
+                            text = f"... exported database: \n {nm1} \n ... prev name: \n {oldname}"
                             show_message_box(stdscr, f"Directory: \n {selected_item} \n {text}")
                     elif os.path.isfile(path):
                         try:
@@ -695,7 +720,9 @@ def main(logfile, admin, test_only):
                         text = ""
                         if selected_item.find(".exported") > 0:
                             nm1 = selected_item.split(".exported")[0]
-                            text = f"... exported database: \n {nm1}"
+                            filepath = os.path.join(DISK_MIRROR_PATH, selected_item)
+                            oldname = maninf.restore_portable_get_oldname(filepath, database=nm1)
+                            text = f"... exported database: \n {nm1} \n ... prev name: \n {oldname}"
                             show_message_box(stdscr, f"Directory: \n {selected_item} \n {text}")
                     elif os.path.isfile(path):
                         try:
@@ -722,7 +749,9 @@ def main(logfile, admin, test_only):
                     show_message_box(stdscr, f"{res}")
                 refresh_panels()
 
-
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
 
             elif key == ord('#'):#   shift-3------------------- VIEW measurement continuously
                 logging.debug(f" key {chr(key)} pressed   ")
@@ -777,6 +806,10 @@ def main(logfile, admin, test_only):
                 # --- "#"
                 refresh_panels()
 
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
+
             elif key == ord('4'):# --------------------------------- INSERT measurement
                 logging.debug(f" key {chr(key)} pressed   ")
                 if (active_panel == 'left' and len(left_items) == 0 ) or (active_panel == 'right' and len(right_items) == 0 ):
@@ -803,7 +836,9 @@ def main(logfile, admin, test_only):
                     #show_message_box(stdscr, f"{res}")
                 refresh_panels()
 
-
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
 
             elif key == ord('5'):# --------------------------------- COPY measurement
                 logging.debug(f" key {chr(key)} pressed   ")
@@ -825,7 +860,7 @@ def main(logfile, admin, test_only):
                     on_copy(name, dbase, other_dbase, stdscr)
                     refresh_panels()
                 else:# ------------------- one panel is disk
-                    if active_panel == 'left' and right_disk_mode: # COPY TO DISK L- R
+                    if active_panel == 'left' and right_disk_mode: # COPY TO DISK L- R ----------------------------------
                         name = left_items[left_idx]
                         dbase = left_db_selected
                         if name and dbase: # copy measurement
@@ -844,7 +879,8 @@ def main(logfile, admin, test_only):
                             else:
                                 logging.debug(f"copy DB to disk: {name}  to {filepath} ")
                                 maninf.backup_portable(filepath, name ) # ONE  DB BACKUP
-                    elif  active_panel == 'right' and left_disk_mode: # COPY TO DISK R - L
+
+                    elif  active_panel == 'right' and left_disk_mode: # COPY TO DISK R - L -----------------------------------------
                         name = right_items[right_idx]
                         dbase = right_db_selected
                         if name and dbase: # copy measurement
@@ -892,7 +928,9 @@ def main(logfile, admin, test_only):
                 refresh_panels() # refresh after copy
 
 
-
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
 
             elif key == ord('6'):# --------------------------------- MOVE measurement
                 logging.debug(f" key {chr(key)} pressed   ")
@@ -926,7 +964,7 @@ def main(logfile, admin, test_only):
                                 logging.debug(f" - not dropping {i} in {name}; ")
                             name = input_dialog(stdscr, f"You drop {name} database yourself ")
                         else:logging.debug("empty string for newname")
-                    else:
+                    else: # COPY AND DELETE
                         logging.debug(f"I am in measurement view and F6 mea=={name}")
                         on_copy(name, dbase, other_dbase, stdscr, wordcopy="MOVE")
                         on_delete_measurement(name, dbase, stdscr, asking=False) # in move
@@ -934,6 +972,9 @@ def main(logfile, admin, test_only):
                 #on_move()
                 #refresh_panels()
 
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
 
             elif key == ord('^'):  # SHIFT-6 rename measurement or disk file
                 logging.debug(f" key {chr(key)} pressed   ")
@@ -1016,6 +1057,9 @@ def main(logfile, admin, test_only):
                                 #    show_message_box(stdscr, f"Rename failed: {res_copy}")
                                 refresh_panels()
 
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
 
             elif key == ord('7'):# --------------------------------- CREATE database
                 logging.debug(f" key {chr(key)} pressed   ")
@@ -1027,6 +1071,9 @@ def main(logfile, admin, test_only):
                     on_create_database(name)
                 refresh_panels()
 
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
 
             elif key == ord('8'): # --------------------------------- DELETE database/measurement
                 logging.debug(f" key {chr(key)} pressed   ")
@@ -1067,13 +1114,17 @@ def main(logfile, admin, test_only):
                 refresh_panels()
 
 
-
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
 
             elif key == ord('r'): # --------------------------------- refresh panels
                 logging.debug(f" key {chr(key)} pressed   ")
                 refresh_panels()
 
-
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
 
             elif key == ord('d'):  # ----------------------------------- CHANGE  DISK MODE --------------
                 logging.debug(f" key {chr(key)} pressed   ")
@@ -1097,13 +1148,19 @@ def main(logfile, admin, test_only):
                         right_offset = 0
                 refresh_panels()
 
-
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
 
             elif key == ord('b'): # --------------------------------- backup ALL  ... to the hardcoded path
                 logging.debug(f" key {chr(key)} pressed   ")
                 on_backup(stdscr)
                 refresh_panels()
 
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
+
             elif key in (curses.KEY_ENTER, 10, 13): # movements throug influxdb or view basics info on measurement
                 logging.debug(f" key ENTER pressed   ")
 
@@ -1123,7 +1180,10 @@ def main(logfile, admin, test_only):
                             text = ""
                             if selected_item.find(".exported") > 0:
                                 nm1 = selected_item.split(".exported")[0]
-                                text = f"... exported database: \n {nm1}"
+                                filepath = os.path.join(DISK_MIRROR_PATH, selected_item)
+                                oldname = maninf.restore_portable_get_oldname(filepath, database=nm1)
+                                text = f"... exported database: \n {nm1} \n ... prev name: \n {oldname}"
+
                             show_message_box(stdscr, f"Directory: \n {selected_item} \n {text}")
                         elif os.path.isfile(path): # When file, show content :)
                             try:
@@ -1169,7 +1229,9 @@ def main(logfile, admin, test_only):
                             text = ""
                             if selected_item.find(".exported") > 0:
                                 nm1 = selected_item.split(".exported")[0]
-                                text = f"... exported database: \n {nm1}"
+                                filepath = os.path.join(DISK_MIRROR_PATH, selected_item)
+                                oldname = maninf.restore_portable_get_oldname(filepath, database=nm1)
+                                text = f"... exported database: \n {nm1} \n ... prev name: \n {oldname}"
                             show_message_box(stdscr, f"Directory: \n {selected_item} \n {text}")
                         elif os.path.isfile(path):
                             try:
@@ -1211,6 +1273,10 @@ def main(logfile, admin, test_only):
             #             right_items = maninf.show_measurements(right_db_selected)
             #             right_idx = 0
 
+            # ================================================================================
+            #
+            # --------------------------------------------------------------------------------
+
             elif key in (ord('q'), 27):  # q or ESC to quit
                 break
 
