@@ -160,7 +160,7 @@ def export_measurement(m1, db1, filepath=None, silent=False):
         if filepath is not None:
             outfilename = filepath
         print(f"\n{fg.yellow}i... saving {outfilename} {fg.default}")
-        CMD = f"influx -username '{u}' -password '{p}' {ssl} -host {m} -database {db1} -execute 'SELECT * FROM {m1} ORDER BY time ASC LIMIT {limit} OFFSET {offset}' -format csv -precision rfc3339"
+        CMD = f"influx -username '{u}' -password '{p}' {ssl} -host {m} -database {db1} -execute 'SELECT * FROM {m1} ORDER BY time DESC LIMIT {limit} OFFSET {offset}' -format csv -precision rfc3339"
         result = sp.run(shlex.split(CMD), capture_output=True, text=True)
         if not result.stdout.strip():
             break
